@@ -1,3 +1,4 @@
+from .__pkginfo__ import version as __version__
 from .api import \
     load_file, \
     load_string, \
@@ -7,12 +8,11 @@ from .api import \
     render_string, \
     render1f, \
     render1s
-from .util import cached_method, cached_function
+from .functions import Functions
 from .jsonutil import loadjson, loadjson_all, dumpjson
+from .util import cached_method, cached_function
 from .yamlutil import loadyaml, loadyaml_all, dumpyaml
 
-from .__pkginfo__ import version as __version__
-
 __all__ = [
     'load_file',
     'load_string',
@@ -23,6 +23,8 @@ __all__ = [
     'render1f',
     'render1s',
 
+    'Functions',
+
     'loadjson',
     'loadjson_all',
     'dumpjson',
