@@ -1,15 +1,11 @@
 from __future__ import annotations
 
-import decimal
-from typing import Dict, List, Union
-
-import dezimal
+from typing import Dict, List, Tuple
 
 from .environment import Environment
-from .exceptions import NoSuchVariableError, NoSuchEnvironmentVariableError
+from .exceptions import NoSuchVariableError, NoSuchEnvironmentVariableError, NoCaseError
 from .util import Singleton, select, substitute, empty, cached_method
-
-Value = Union[None, str, bool, int, float, decimal.Decimal, dezimal.Dezimal, List['Value'], Dict[str, 'Value']]
+from .value import Value
 
 
 class Node:
@@ -106,9 +102,13 @@ class Else(Node):
         self.otherwise: Node = Empty()
 
     def evaluate_body(self, env: Environment):
+        # noinspection PyBroadException
         try:
             return self.body.evaluate(env)
-        except (NoSuchEnvironmentVariableError, ArithmeticError, ValueError, TypeError):
+        except (NoSuchEnvironmentVariableError, ArithmeticError, ValueError, TypeError, LookupError):
+            return None
+        except Exception as exc:
+            print(f"WARNING: Unexpected exception {exc}")
             return None
 
     def evaluate(self, env: Environment) -> Value:
@@ -126,7 +126,8 @@ class Object(Node):
     def evaluate(self, env: Environment) -> Value:
         result = {}
         for key, node in self.children.items():
-            result[key] = node.evaluate(env)
+            key_f = Format(self, key).evaluate(env)
+            result[key_f] = node.evaluate(env)
         return result
 
 
@@ -242,6 +243,18 @@ class Any(Node):
         return False
 
 
+class Case(Node):
+    def __init__(self, parent: Node):
+        super().__init__(parent)
+        self.cases: List[Tuple[Node, Node]] = []
+
+    def evaluate(self, env: Environment) -> Value:
+        for condition, action in self.cases:
+            if condition.evaluate(env):
+                return action.evaluate(env)
+        raise NoCaseError()
+
+
 class Format(Node):
     def __init__(self, parent: Node, value: Value):
         super().__init__(parent)
@@ -250,7 +263,10 @@ class Format(Node):
     def evaluate(self, env: Environment) -> Value:
         def subst(key: str) -> str:
             if key[:1] == "$":
-                return env.get_dyn(key[1:])
-            return self.get_let(key).evaluate(env)
+                getter = GetDyn(parent=self, path=key[1:].split("."))
+            else:
+                getter = GetLet(parent=self, path=key.split("."))
+            result = getter.evaluate(env)
+            return str(result)
 
         return substitute(self.value, subst)
